@@ -136,7 +136,7 @@ int read_main_config_file(char *main_config_file) {
 			continue;
 
 		/* get the variable name */
-		if((temp_ptr = my_strtok(input, "=")) == NULL) {
+		if((temp_ptr = my_strtok_with_free(input, "=", FALSE)) == NULL) {
 			asprintf(&error_message, "NULL variable");
 			error = TRUE;
 			break;
@@ -148,7 +148,7 @@ int read_main_config_file(char *main_config_file) {
 			}
 
 		/* get the value */
-		if((temp_ptr = my_strtok(NULL, "\n")) == NULL) {
+		if((temp_ptr = my_strtok_with_free(NULL, "\n", FALSE)) == NULL) {
 			asprintf(&error_message, "NULL value");
 			error = TRUE;
 			break;
@@ -158,6 +158,7 @@ int read_main_config_file(char *main_config_file) {
 			error = TRUE;
 			break;
 			}
+		temp_ptr = my_strtok_with_free(NULL, "\n", TRUE);
 		strip(variable);
 		strip(value);
 
@@ -176,8 +177,12 @@ int read_main_config_file(char *main_config_file) {
 			}
 
 		else if(!strcmp(variable, "website_url")) {
+			int lth;
 			my_free(website_url);
 			website_url = strdup(value);
+			lth = strlen(website_url);
+			if (website_url[lth-1] == '/')
+				website_url[lth-1] = '\0';
 			}
 
 		else if(!strcmp(variable, "loadctl_options"))
@@ -925,7 +930,7 @@ int read_main_config_file(char *main_config_file) {
 				break;
 				}
 			}
-
+			
 		else if(!strcmp(variable, "status_update_interval")) {
 
 			status_update_interval = atoi(value);
@@ -1177,6 +1182,38 @@ int read_main_config_file(char *main_config_file) {
 		else if(!strcmp(variable,"host_down_disable_service_checks")) {
 			host_down_disable_service_checks = strtoul(value, NULL, 0);
 		}
+		else if(!strcmp(variable,"service_skip_check_dependency_status")) {
+			service_skip_check_dependency_status = atoi(value);
+			if(service_skip_check_dependency_status < -1 || service_skip_check_dependency_status > 3) {
+				asprintf(&error_message, "Illegal value for service_skip_check_dependency_status");
+				error = TRUE;
+				break;
+			}
+		}
+		else if(!strcmp(variable,"service_skip_check_parent_status")) {
+			service_skip_check_parent_status = atoi(value);
+			if(service_skip_check_parent_status < -1 || service_skip_check_parent_status > 3) {
+				asprintf(&error_message, "Illegal value for service_skip_check_parent_status");
+				error = TRUE;
+				break;
+			}
+		}
+		else if(!strcmp(variable,"service_skip_check_host_down_status")) {
+			service_skip_check_host_down_status = atoi(value);
+			if(service_skip_check_host_down_status < -1 || service_skip_check_host_down_status > 3) {
+				asprintf(&error_message, "Illegal value for service_skip_check_host_down_status");
+				error = TRUE;
+				break;
+			}
+		}
+		else if(!strcmp(variable,"host_skip_check_dependency_status")) {
+			host_skip_check_dependency_status = atoi(value);
+			if(host_skip_check_dependency_status < -1 || host_skip_check_dependency_status > 3) {
+				asprintf(&error_message, "Illegal value for host_skip_check_dependency_status");
+				error = TRUE;
+				break;
+			}
+		}
 		/* we don't know what this variable is... */
 		else {
 			asprintf(&error_message, "UNKNOWN VARIABLE");
@@ -1320,7 +1357,7 @@ int read_resource_file(char *resource_file) {
 		strip(input);
 
 		/* get the variable name */
-		if((temp_ptr = my_strtok(input, "=")) == NULL) {
+		if((temp_ptr = my_strtok_with_free(input, "=", FALSE)) == NULL) {
 			logit(NSLOG_CONFIG_ERROR, TRUE, "Error: NULL variable - Line %d of resource file '%s'", current_line, resource_file);
 			error = TRUE;
 			break;
@@ -1331,7 +1368,7 @@ int read_resource_file(char *resource_file) {
 			}
 
 		/* get the value */
-		if((temp_ptr = my_strtok(NULL, "\n")) == NULL) {
+		if((temp_ptr = my_strtok_with_free(NULL, "\n", FALSE)) == NULL) {
 			logit(NSLOG_CONFIG_ERROR, TRUE, "Error: NULL variable value - Line %d of resource file '%s'", current_line, resource_file);
 			error = TRUE;
 			break;
@@ -1340,6 +1377,7 @@ int read_resource_file(char *resource_file) {
 			error = TRUE;
 			break;
 			}
+		temp_ptr = my_strtok_with_free(NULL, "\n", TRUE);
 
 		/* what should we do with the variable/value pair? */
 
